From 01524938c6d455b3b8e3a35f7b82b7de71de2c19 Mon Sep 17 00:00:00 2001
From: hxp <ale99527@vip.qq.com>
Date: 星期一, 18 十一月 2024 16:51:26 +0800
Subject: [PATCH] 10261 【越南】【砍树】【英文】【tqxbqy】【btgotq】头像框,头像(补充跨服榜单Value3、Value4,包含古神参与、召集、积分榜,boss历练活动榜、古宝养成活动榜、骑宠养成活动榜、仙匣秘境活动榜;)

---
 ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GM/Commands/Success.py |   15 ++++++++++++---
 1 files changed, 12 insertions(+), 3 deletions(-)

diff --git a/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GM/Commands/Success.py b/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GM/Commands/Success.py
index f187085..b2491a0 100644
--- a/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GM/Commands/Success.py
+++ b/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GM/Commands/Success.py
@@ -19,6 +19,7 @@
 import ShareDefine
 import PlayerSuccess
 import GameWorld
+import PlayerControl
 
 #逻辑实现
 ## GM命令执行入口
@@ -72,6 +73,7 @@
             if succType not in resetTypeList:
                 resetTypeList.append(succType)
             PlayerSuccess.SetSuccHasGot(curPlayer, succID, False)
+            PlayerSuccess.SetSuccPassportAwardHasGot(curPlayer, succID, False)
             PlayerSuccess.SetSuccFinish(curPlayer, succID, False)
             PlayerSuccess.SetPDictValue(curPlayer, ChConfig.Def_PDict_Success_LastDay % (succID), 0)
             PlayerSuccess.SetSuccFinishValue(curPlayer, succType, succDataObj.condition, 0)
@@ -82,6 +84,8 @@
     PlayerSuccess.Sync_SuccessInfo(curPlayer, [], True)
     # 同步成就领奖记录
     PlayerSuccess.Sync_SuccTypeIndexAwardRecord(curPlayer, [], True)
+    PlayerControl.NomalDictSetProperty(curPlayer, ChConfig.Def_PDict_Success_ScoreAward, 0)
+    PlayerSuccess.Sync_SuccessScoreAward(curPlayer)
     GameWorld.DebugAnswer(curPlayer, "重置成就类型:%s" % resetTypeList)
     return
 
@@ -100,14 +104,18 @@
         
         for succDataObj in succDataList:
             succID = succDataObj.succID
-            if not PlayerSuccess.GetSuccHasGot(curPlayer, succID):
+            if not PlayerSuccess.GetSuccHasGot(curPlayer, succID) and not PlayerSuccess.GetSuccPassportAwardHasGot(curPlayer, succID):
                 continue
             PlayerSuccess.SetSuccHasGot(curPlayer, succID, False)
+            PlayerSuccess.SetSuccPassportAwardHasGot(curPlayer, succID, False)
+            PlayerSuccess.SetSuccFinish(curPlayer, succID) # 有重置领奖的ID需要重新设置为已完成
             resetIDList.append(succID)
             
     # 同步成就领奖记录
     PlayerSuccess.Sync_SuccTypeIndexAwardRecord(curPlayer, resetIDList, True)
     GameWorld.DebugAnswer(curPlayer, "重置成就ID领奖:%s" % resetIDList)
+    PlayerControl.NomalDictSetProperty(curPlayer, ChConfig.Def_PDict_Success_ScoreAward, 0)
+    PlayerSuccess.Sync_SuccessScoreAward(curPlayer)
     return
 
 def __DoPrintSuccess(curPlayer, msgList):
@@ -132,8 +140,9 @@
                 GameWorld.DebugAnswer(curPlayer, "成就类型: %s" % succType)
             isFinish = PlayerSuccess.GetSuccIsFinish(curPlayer, succID)
             hasGot = PlayerSuccess.GetSuccHasGot(curPlayer, succID)
-            GameWorld.DebugAnswer(curPlayer, "    id=%s 条件:%s 进度:%s/%s 完成:%s 领奖:%s" 
-                                  % (succID, succDataObj.condition, value, succDataObj.needCnt, isFinish, hasGot))
+            passportHasGot = PlayerSuccess.GetSuccPassportAwardHasGot(curPlayer, succID)
+            GameWorld.DebugAnswer(curPlayer, "    id=%s 条件:%s 进度:%s/%s 完成:%s 领奖:%s %s" 
+                                  % (succID, succDataObj.condition, value, succDataObj.needCnt, isFinish, hasGot, passportHasGot))
             
     return
 

--
Gitblit v1.8.0